import { type FioriElementsApp, type LROPSettings } from '@sap-ux/fiori-elements-writer';
import type { Editor } from 'mem-fs-editor';
import type { AppInfo, QfaJsonConfig } from '../app/types';
import type { AbapDeployConfig } from '@sap-ux/ui5-config';
/**
 * Generates the deployment configuration for an ABAP application.
 *
 * @param {AppInfo} app - Application info containing `url` and `repoName`.
 * @param {QfaJsonConfig} qfaJson - The QFA JSON configuration containing app details.
 * @returns {AbapDeployConfig} The deployment configuration containing `target` and `app` info.
 */
export declare const getAbapDeployConfig: (app: AppInfo, qfaJson: QfaJsonConfig) => AbapDeployConfig;
/**
 * Gets the application configuration based on the provided user answers and manifest data.
 * This configuration will be used to initialize a new Fiori application.
 *
 * @param {AppInfo} app - Selected app information.
 * @param {string} extractedProjectPath - Path where the app files are extracted.
 * @param {QfaJsonConfig} qfaJson - The QFA JSON configuration containing app details.
 * @param {Editor} fs - The file system editor to manipulate project files.
 * @returns {Promise<FioriElementsApp<LROPSettings>>} - A promise resolving to the generated app configuration.
 * @throws {Error} - Throws an error if there are issues generating the configuration.
 */
export declare function getAppConfig(app: AppInfo, extractedProjectPath: string, qfaJson: QfaJsonConfig, fs: Editor): Promise<FioriElementsApp<LROPSettings>>;
//# sourceMappingURL=app-config.d.ts.map