import type { AbapServiceProvider, AppIndex } from '@sap-ux/axios-extension';
import type { AppInfo, AppItem } from '../app/types';
/**
 * Returns the details for the YUI prompt.
 *
 * @returns step details
 */
export declare function getYUIDetails(): {
    name: string;
    description: string;
}[];
/**
 * Returns the prompt details for the selected application.
 *
 * @param {AppItem} app - The application item to extract details from.
 * @returns {{ name: string; value: AppInfo }} The extracted details including name and value.
 */
export declare const extractAppData: (app: AppItem) => {
    name: string;
    value: AppInfo;
};
/**
 * Formats the application list into selectable choices.
 *
 * @param {AppIndex} appList - List of applications retrieved from the system.
 * @returns {Array<{ name: string; value: AppInfo }>} The formatted choices for selection.
 */
export declare const formatAppChoices: (appList: AppIndex) => Array<{
    name: string;
    value: AppInfo;
}>;
/**
 * Fetches the application list for the selected system.
 *
 * @param {AbapServiceProvider} serviceProvider - The ABAP service provider.
 * @param {string} appId - Application ID to be downloaded.
 * @returns {Promise<AppIndex>} A list of applications filtered by source template.
 */
export declare function fetchAppListForSelectedSystem(serviceProvider: AbapServiceProvider, appId?: string): Promise<AppIndex>;
//# sourceMappingURL=prompt-helpers.d.ts.map