/// <reference types="node" />
import type { SystemSelectionAnswers } from '../app/types';
/**
 * Much of the values returned by the app downloader prompting are derived from prompt answers and are not direct answer values.
 * Since inquirer does not provide a way to return values that are not direct answers from prompts, this class will maintain the derived values
 * across prompts statically for the lifespan of the prompting session.
 *
 */
export declare class PromptState {
    private static _systemSelection;
    private static _downloadedAppPackage?;
    /**
     * Returns the current state of the service config.
     *
     * @returns {SystemSelectionAnswers} service config
     */
    static get systemSelection(): SystemSelectionAnswers;
    /**
     * Set the state of the system selection.
     *
     * @param {SystemSelectionAnswers} value - system selection value
     */
    static set systemSelection(value: Partial<SystemSelectionAnswers>);
    /**
     * Set the downloaded app package.
     */
    static set downloadedAppPackage(archive: Buffer);
    /**
     * Returns the downloaded app package.
     *
     * @returns {Buffer} downloaded app package
     */
    static get downloadedAppPackage(): Buffer;
    /**
     * Get the baseURL from the connected system's service provider defaults.
     *
     * @returns {string | undefined} baseURL
     */
    static get baseURL(): string | undefined;
    /**
     * Get the sap-client parameter from the connected system's service provider defaults.
     *
     * @returns {string | undefined} sap-client
     */
    static get sapClient(): string | undefined;
    static reset(): void;
}
//# sourceMappingURL=prompt-state.d.ts.map