"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PromptState = void 0;
/**
 * Much of the values returned by the app downloader prompting are derived from prompt answers and are not direct answer values.
 * Since inquirer does not provide a way to return values that are not direct answers from prompts, this class will maintain the derived values
 * across prompts statically for the lifespan of the prompting session.
 *
 */
class PromptState {
    static _systemSelection = {};
    static _downloadedAppPackage;
    /**
     * Returns the current state of the service config.
     *
     * @returns {SystemSelectionAnswers} service config
     */
    static get systemSelection() {
        return this._systemSelection;
    }
    /**
     * Set the state of the system selection.
     *
     * @param {SystemSelectionAnswers} value - system selection value
     */
    static set systemSelection(value) {
        this._systemSelection = value;
    }
    /**
     * Set the downloaded app package.
     */
    static set downloadedAppPackage(archive) {
        this._downloadedAppPackage = archive;
    }
    /**
     * Returns the downloaded app package.
     *
     * @returns {Buffer} downloaded app package
     */
    static get downloadedAppPackage() {
        return this._downloadedAppPackage ?? Buffer.alloc(0);
    }
    /**
     * Get the baseURL from the connected system's service provider defaults.
     *
     * @returns {string | undefined} baseURL
     */
    static get baseURL() {
        return this._systemSelection.connectedSystem?.serviceProvider?.defaults?.baseURL;
    }
    /**
     * Get the sap-client parameter from the connected system's service provider defaults.
     *
     * @returns {string | undefined} sap-client
     */
    static get sapClient() {
        return this._systemSelection.connectedSystem?.serviceProvider?.defaults?.params?.['sap-client'];
    }
    static reset() {
        PromptState.systemSelection = {};
        PromptState._downloadedAppPackage = undefined;
    }
}
exports.PromptState = PromptState;
//# sourceMappingURL=prompt-state.js.map