"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.downloadApp = exports.extractZip = void 0;
const adm_zip_1 = __importDefault(require("adm-zip"));
const path_1 = require("path");
const prompt_state_1 = require("../prompts/prompt-state");
const i18n_1 = require("./i18n");
const logger_1 = __importDefault(require("../utils/logger"));
/**
 * Extracts a ZIP archive to a temporary directory.
 *
 * @param {string} extractedProjectPath - The path where the archive should be extracted.
 * @param {Buffer} archive - The ZIP archive buffer.
 * @param {Editor} fs - The file system editor.
 */
async function extractZip(extractedProjectPath, archive, fs) {
    try {
        const zip = new adm_zip_1.default(archive);
        zip.getEntries().forEach(function (zipEntry) {
            if (!zipEntry.isDirectory) {
                // Extract the file content
                const fileContent = zipEntry.getData().toString('utf8');
                // Load the file content into mem-fs for use in the temporary extracted project directory
                fs.write((0, path_1.join)(extractedProjectPath, zipEntry.entryName), fileContent);
            }
        });
    }
    catch (error) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.appDownloadErrors.zipExtractionError', { error: error.message }));
    }
}
exports.extractZip = extractZip;
/**
 * Downloads application files from the ABAP repository.
 *
 * @param {string} repoName - The repository name of the application.
 */
async function downloadApp(repoName) {
    const serviceProvider = prompt_state_1.PromptState.systemSelection?.connectedSystem?.serviceProvider;
    const downloadedAppPackage = await serviceProvider.getUi5AbapRepository().downloadFiles(repoName);
    // store downloaded package in prompt state
    prompt_state_1.PromptState.downloadedAppPackage = downloadedAppPackage;
}
exports.downloadApp = downloadApp;
//# sourceMappingURL=download-utils.js.map