"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runPostAppGenHook = void 0;
const logger_1 = __importDefault(require("./logger"));
const i18n_1 = require("./i18n");
/**
 * Executes the post-generation command for the app.
 * Runs the specified command in the context of the generated project, typically for tasks like refreshing or reloading the project in the editor.
 *
 * @param {RepoAppGenContext} context - The context containing the project path, post-generation command, and optional VSCode instance.
 */
async function runPostAppGenHook(context) {
    try {
        // Ensure that context has necessary values before proceeding
        if (!context.vscodeInstance) {
            logger_1.default.logger?.error((0, i18n_1.t)('error.eventHookErrors.vscodeInstanceMissing'));
        }
        if (!context.postGenCommand || context.postGenCommand.trim() === '') {
            logger_1.default.logger?.error((0, i18n_1.t)('error.eventHookErrors.postGenCommandMissing'));
        }
        // Execute the post-generation command
        await context.vscodeInstance?.commands?.executeCommand?.(context.postGenCommand, {
            fsPath: context.path
        });
    }
    catch (e) {
        logger_1.default.logger?.error((0, i18n_1.t)('error.eventHookErrors.commandExecutionFailed', e.message));
    }
}
exports.runPostAppGenHook = runPostAppGenHook;
//# sourceMappingURL=event-hook.js.map